var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import PropTypes from 'prop-types';
/**
 * Creates props for a component that opens the popup when clicked.
 *
 * @param {object} popupState the argument passed to the child function of
 * `PopupState`
 */
export function bindTrigger(_a) {
    var isOpen = _a.isOpen, open = _a.open, popupId = _a.popupId, variant = _a.variant;
    var _b;
    return _b = {},
        _b[variant === 'popover' ? 'aria-owns' : 'aria-describedby'] = isOpen ? popupId : null,
        _b['aria-haspopup'] = true,
        _b.onClick = open,
        _b;
}
/**
 * Creates props for a component that toggles the popup when clicked.
 *
 * @param {object} popupState the argument passed to the child function of
 * `PopupState`
 */
export function bindToggle(_a) {
    var isOpen = _a.isOpen, toggle = _a.toggle, popupId = _a.popupId, variant = _a.variant;
    var _b;
    return _b = {},
        _b[variant === 'popover' ? 'aria-owns' : 'aria-describedby'] = isOpen ? popupId : null,
        _b['aria-haspopup'] = true,
        _b.onClick = toggle,
        _b;
}
/**
 * Creates props for a component that opens the popup while hovered.
 *
 * @param {object} popupState the argument passed to the child function of
 * `PopupState`
 */
export function bindHover(_a) {
    var isOpen = _a.isOpen, open = _a.open, close = _a.close, popupId = _a.popupId, variant = _a.variant;
    var _b;
    return _b = {},
        _b[variant === 'popover' ? 'aria-owns' : 'aria-describedby'] = isOpen ? popupId : null,
        _b['aria-haspopup'] = true,
        _b.onMouseEnter = open,
        _b.onMouseLeave = close,
        _b;
}
/**
 * Creates props for a `Popover` component.
 *
 * @param {object} popupState the argument passed to the child function of
 * `PopupState`
 */
export function bindPopover(_a) {
    var isOpen = _a.isOpen, anchorEl = _a.anchorEl, close = _a.close, popupId = _a.popupId;
    return {
        id: popupId,
        anchorEl: anchorEl,
        open: isOpen,
        onClose: close,
    };
}
/**
 * Creates props for a `Menu` component.
 *
 * @param {object} popupState the argument passed to the child function of
 * `PopupState`
 */
export var bindMenu = bindPopover;
/**
 * Creates props for a `Popper` component.
 *
 * @param {object} popupState the argument passed to the child function of
 * `PopupState`
 */
export function bindPopper(_a) {
    var isOpen = _a.isOpen, anchorEl = _a.anchorEl, popupId = _a.popupId;
    return {
        id: popupId,
        anchorEl: anchorEl,
        open: isOpen,
    };
}
var eventOrAnchorElWarned = false;
var PopupState = /** @class */ (function (_super) {
    __extends(PopupState, _super);
    function PopupState() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = { anchorEl: null };
        _this.handleToggle = function (eventOrAnchorEl) {
            if (_this.state.anchorEl) {
                _this.handleClose();
            }
            else {
                _this.handleOpen(eventOrAnchorEl);
            }
        };
        _this.handleOpen = function (eventOrAnchorEl) {
            if (!eventOrAnchorElWarned && !eventOrAnchorEl) {
                eventOrAnchorElWarned = true;
                console.error('eventOrAnchorEl should be defined'); // eslint-disable-line no-console
            }
            var anchorEl = null;
            if (eventOrAnchorEl instanceof HTMLElement) {
                anchorEl = eventOrAnchorEl;
            }
            else if (eventOrAnchorEl instanceof Event && eventOrAnchorEl.target instanceof HTMLElement) {
                anchorEl = eventOrAnchorEl.target;
            }
            _this.setState(function (state) { return (__assign({}, state, { anchorEl: anchorEl })); });
        };
        _this.handleClose = function () { return _this.setState({ anchorEl: null }); };
        _this.handleSetOpen = function (open, eventOrAnchorEl) {
            if (open) {
                _this.handleOpen(eventOrAnchorEl);
            }
            else {
                _this.handleClose();
            }
        };
        return _this;
    }
    PopupState.prototype.render = function () {
        var _a = this.props, children = _a.children, popupId = _a.popupId, variant = _a.variant;
        var anchorEl = this.state.anchorEl;
        var isOpen = Boolean(anchorEl);
        var result = children({
            open: this.handleOpen,
            close: this.handleClose,
            toggle: this.handleToggle,
            setOpen: this.handleSetOpen,
            isOpen: isOpen,
            anchorEl: anchorEl,
            popupId: popupId || undefined,
            variant: variant,
        });
        return (result == null) ? null : result;
    };
    PopupState.propTypes = {
        /**
         * The render function.
         *
         * @param {object} props the properties injected by `PopupState`:
         * <ul>
         *   <li>`open(eventOrAnchorEl)`: opens the popup</li>
         *   <li>`close()`: closes the popup</li>
         *   <li>`toggle(eventOrAnchorEl)`: opens the popup if it is closed, or
         *     closes the popup if it is open.
         *   </li>
         *   <li>`setOpen(open, [eventOrAnchorEl])`: sets whether the popup is open.
         *     `eventOrAnchorEl` is required if `open` is truthy.
         *   </li>
         *   <li>`isOpen`: `true`/`false` if the popup is open/closed</li>
         *   <li>`anchorEl`: the current anchor element (`null` the popup is closed)</li>
         *   <li>`popupId`: the `popupId` prop you passed</li>
         * </ul>
         *
         * @returns {React.Node} the content to display
         */
        children: PropTypes.func.isRequired,
        /**
         * The `id` property to use for the popup.  Will be passed to the render
         * function as `bindPopup.id`, and also used for the `aria-owns` property
         * passed to the trigger component via `bindTrigger`.
         */
        popupId: PropTypes.string,
        /**
         * Which type of popup you are controlling.  Use `'popover'` for `Popover`
         * and `Menu`; use `'popper'` for `Popper`s.  Right now this only affects
         * whether `aria-owns` or `aria-describedby` is used on the trigger
         * component.
         */
        variant: PropTypes.oneOf(['popover', 'popper']).isRequired,
    };
    return PopupState;
}(React.Component));
export default PopupState;
//# sourceMappingURL=../../src/dist/ux/PopupState.js.map